﻿--[[----------------------------------------------------------------------
      VanasKoSGUI - Part of VanasKoS
Handles the main gui frame
------------------------------------------------------------------------]]

local L = AceLibrary("AceLocale-2.2"):new("VanasKoS");

VanasKoSGUI = VanasKoS:NewModule("GUI");
local VanasKoSGUI = VanasKoSGUI;

local dewdrop = AceLibrary("Dewdrop-2.0");

local listHandler = { };

function VanasKoSGUI:AddConfigOption(name, option)
	if(not self.ConfigurationOptions) then
		self.ConfigurationOptions = {
			type = 'group',
			args = {
			}
		}
	end
	
	self.ConfigurationOptions.args[name] = option;
end

function VanasKoSGUI:GetListName(listid)
	for k,v in pairs(VANASKOS.Lists) do
		if(v[1] == listid) then
			return v[2];
		end
	end
	return listid;
end

function VanasKoSGUI:OnInitialize()
	VanasKoS:RegisterDefaults("GUI", "profile", {
		GUILocked = true,
		GUIMoved = false,
		
		sortListBy = "name",
	});
	
	self.db = VanasKoS:AcquireDBNamespace("GUI");
	
	UIPanelWindows["VanasKoSFrame"] = { area = "left", pushable = 1, whileDead = 1 };

	local showOptions = { 
		type = 'group',
		args = {
			sort = {
				type = 'group',
				name = L["sort"],
				desc = L["sort"],
				order = 1,
				args = {
					byname = {
						type = "toggle",
						name = L["by name"],
						desc = L["sort by name"],
						isRadio = true,
						order = 1,
						get = function()
							if(VanasKoSGUI.db.profile.sortListBy == "name") then
								return true;
							else
								return false;
							end
						end,
						set = function()
							VanasKoSGUI.db.profile.sortListBy = "name";
							VanasKoSGUI:ScrollFrameUpdate();
						end
					},
					bylevel = {
						type = "toggle",
						name = L["by level"],
						desc = L["sort by level"],
						isRadio = true,
						order = 2,
						get = function()
							if(VanasKoSGUI.db.profile.sortListBy == "level") then
								return true;
							else
								return false;
							end
						end,
						set = function()
							VanasKoSGUI.db.profile.sortListBy = "level";
							VanasKoSGUI:ScrollFrameUpdate();
						end
					},
					byreason = {
						type = "toggle",
						name = L["by reason"],
						desc = L["sort by reason"],
						isRadio = true,
						order = 3,
						get = function()
							if(VanasKoSGUI.db.profile.sortListBy == "reason") then
								return true;
							else
								return false;
							end
						end,
						set = function()
							VanasKoSGUI.db.profile.sortListBy = "reason";
							VanasKoSGUI:ScrollFrameUpdate();
						end
					},
					bylastseen = {
						type = "toggle",
						name = L["by last seen"],
						desc = L["sort by last seen"],
						isRadio = true,
						order = 4,
						get = function()
							if(VanasKoSGUI.db.profile.sortListBy == "lastseen") then
								return true;
							else
								return false;
							end
						end,
						set = function()
							VanasKoSGUI.db.profile.sortListBy = "lastseen";
							VanasKoSGUI:ScrollFrameUpdate();
						end
					},
					bycreator = {
						type = "toggle",
						name = L["by creator"],
						desc = L["sort by creator"],
						isRadio = true,
						order = 5,
						get = function()
							if(VanasKoSGUI.db.profile.sortListBy == "creator") then
								return true;
							else
								return false;
							end
						end,
						set = function()
							VanasKoSGUI.db.profile.sortListBy = "creator";
							VanasKoSGUI:ScrollFrameUpdate();
						end
					},
				}
			}
		}
	};
	
	VanasKoSListFrameShowButton:SetScript("OnClick", function()
			dewdrop:Register(this,
				'children', showOptions,
				'point', "TOPLEFT",
				'dontHook', true,
				'relativePoint', "TOPRIGHT"
			);
			this:SetScript("OnClick", function()
				if(dewdrop:IsOpen(this)) then
					dewdrop:Close();
				else
					dewdrop:Open(this);
				end
			end);
			this:GetScript("OnClick")();
	end);
	
	VanasKoSListFrameConfigurationButton:SetScript("OnClick", function()
			dewdrop:Register(this, 
							'children', self.ConfigurationOptions,
							'point', "TOPLEFT",
							'dontHook', true,
							'relativePoint', "TOPRIGHT");
			this:SetScript("OnClick", function()
				if(dewdrop:IsOpen(this)) then
					dewdrop:Close();
				else
					dewdrop:Open(this);
				end
			end);
			this:GetScript("OnClick")();
	end);
	
	self:RegisterEvent("VanasKoS_List_Added", "InitializeDropDowns");
	
	self:AddConfigOption("GUI", {
		type = 'group',
		name = "GUI",
		desc = "Main GUI Options",
		args = {
			locked = { 
				type = 'toggle',
				name = L["Locked"],
				desc = L["Locks the Main Window"],
				order = 1,
				set = function() VanasKoSGUI.db.profile.GUILocked = not VanasKoSGUI.db.profile.GUILocked; end,
				get = function() return VanasKoSGUI.db.profile.GUILocked; end,
			},
			reset = {
				type = 'execute',
				name = L["Reset Position"],
				desc = L["Resets the Position of the Main Window"],
				order = 2,
				func = function() VanasKoSGUI.db.profile.GUIMoved = false; HideUIPanel(VanasKoSFrame); ShowUIPanel(VanasKoSFrame); end,
			}
		},
	});
	
	VanasKoSListFrameSearchBox:SetScript("OnTextChanged", function() VanasKoSGUI:ScrollFrameUpdate(); end);
	
	VanasKoSFrame:RegisterForDrag("LeftButton");
	VanasKoSFrame:SetScript("OnDragStart",
								function()
									if(VanasKoSGUI.db.profile.GUILocked) then
										return;
									end
									VanasKoSFrame:StartMoving();
								end);
	VanasKoSFrame:SetScript("OnDragStop",
								function()
									VanasKoSFrame:StopMovingOrSizing();
									VanasKoSGUI.db.profile.GUIMoved = true;
								end);
end

function VanasKoSGUI:InitializeDropDowns()
	UIDropDownMenu_Initialize(VanasKoSFrameChooseListDropDown, 
		function() 
			local lists = VANASKOS.Lists;
			local i = 0;
			for k,v in self:pairsByKeys(lists, nil) do
				local button = UIDropDownMenu_CreateInfo();
				button.text = v[2];
				button.value = v[1];
				button.func = function() 
						UIDropDownMenu_SetSelectedValue(VanasKoSFrameChooseListDropDown, this.value);
						VANASKOS.showList = this.value;
						VanasKoSGUI:ScrollFrameUpdate();
				end
				UIDropDownMenu_AddButton(button); 
				i = i + 1;
			end
	end);
	UIDropDownMenu_SetSelectedValue(VanasKoSFrameChooseListDropDown, "PLAYERKOS");
end

function VanasKoSGUI:OnEnable()
	self:RegisterEvent("VanasKoS_List_Entry_Added", function() VanasKoSGUI:ScrollFrameUpdate(); end);
	self:RegisterEvent("VanasKoS_List_Entry_Removed", function() VanasKoSGUI:ScrollFrameUpdate(); end);
end

function VanasKoSGUI:OnDisable()
end

--[[----------------------------------------------------------------------
		GUI Functions
------------------------------------------------------------------------]]

VANASKOS.selectedEntry = nil;

local VANASKOSFRAME_SUBFRAMES = { "VanasKoSListFrame", "VanasKoSAboutFrame" };

function VanasKoSGUI:GUIFrame_ShowSubFrame(frameName)
	for index, value in pairs(VANASKOSFRAME_SUBFRAMES) do
		if(value == frameName) then
			getglobal(value):Show();
		else
			getglobal(value):Hide();
		end
	end
end

function VanasKoSGUI:GUIShowChangeDialog()
	local dialog = nil;
	if(VANASKOS.selectedEntry) then
		dialog = StaticPopup_Show("VANASKOS_CHANGE_ENTRY");
		local name = self:GetSelectedEntryName();
		local reason = "";
		local list = self:GetCurrentShownList();
		if(VANASKOS.showList == "PLAYERKOS" or VANASKOS.showList == "GUILDKOS" or VANASKOS.showList == "HATELIST" or VANASKOS.showList == "NICELIST") then
			reason = list[string.lower(name)].reason;
		end
		getglobal(dialog:GetName() .. "EditBox"):SetText(reason);
	end
end

function VanasKoSGUI:GetCurrentShownList()
	return VanasKoS:GetList(VANASKOS.showList);
end

function VanasKoSGUI:GUIChangeKoSReason(reason)
	local name = self:GetSelectedEntryName();
	local list = self:GetCurrentShownList();
	list[string.lower(name)].reason = reason;
	self:ScrollFrameUpdate();
end

function VanasKoSGUI:GetListEntryForID(id)
	local listVar = self:GetCurrentShownList();
	local listIndex = 1;
			
	if(listVar == nil) then
		return nil;
	end

	for k,v in self:SortedList(listVar) do
		if(listIndex == id) then
			return k, v;
		end
		listIndex = listIndex + 1;
	end
end

function VanasKoSGUI:GetSelectedEntryName()
	if(VANASKOS.selectedEntry) then
			local listVar = self:GetCurrentShownList();
			local listIndex = 1;
			
			if(listVar == nil) then
				self:GUIHideButtons(1, 10);
				return nil;
			end

			for k,v in self:SortedList(listVar) do
				if(listIndex == VANASKOS.selectedEntry) then
					return k;
				end
				listIndex = listIndex + 1;
			end

	end
	return nil;
end

function VanasKoSGUI:GetSelectedButtonNumber()
	if(VANASKOS.selectedEntry) then
			local listVar = self:GetCurrentShownList();
			local listIndex = 1;
			
			if(listVar == nil) then
				self:GUIHideButtons(1, 10);
				return nil;
			end

			for k,v in self:SortedList(listVar) do
				if(listIndex == VANASKOS.selectedEntry) then
					return listIndex;
				end
				listIndex = listIndex + 1;
			end

	end
	return nil;
end

function VanasKoSGUI:RemoveEntry()
	VanasKoS:RemoveEntry(VANASKOS.showList, VanasKoSGUI:GetSelectedEntryName());
end

function VanasKoSGUI:ListButton_OnClick(button, frame)
	if(button == "LeftButton") then
		VANASKOS.selectedEntry = frame:GetID();
		self:ScrollFrameUpdate();
	else
		VANASKOS.selectedEntry = frame:GetID();
		self:ScrollFrameUpdate();
	end
	if(listHandler[VANASKOS.showList] and listHandler[VANASKOS.showList].ListButtonOnClick) then
		listHandler[VANASKOS.showList]:ListButtonOnClick(button, frame);
	end
end

function VanasKoSGUI:ListButton_OnEnter(button, frame)
	if(listHandler[VANASKOS.showList] and listHandler[VANASKOS.showList].ListButtonOnEnter) then
		listHandler[VANASKOS.showList]:ListButtonOnEnter(button, frame);
	end
end

function VanasKoSGUI:ListButton_OnLeave(button, frame)
	if(listHandler[VANASKOS.showList] and listHandler[VANASKOS.showList].ListButtonOnLeave) then
		listHandler[VANASKOS.showList]:ListButtonOnLeave(button, frame);
	end
end

function VanasKoSGUI:GUIHideButtons(minimum, maximum)
	for i=minimum,maximum,1 do
		local button = getglobal("VanasKoSListFrameListButton" .. i);
		if(button ~= nil) then
			button:Hide();
		end
	end
end

function VanasKoSGUI:GUIShowButtons(minimum, maximum)
	for i=minimum,maximum,1 do
		local button = getglobal("VanasKoSListFrameListButton" .. i);
		button:Show();
	end
end

function VanasKoSGUI:pairsByKeys (t, fSort, fFilter)
	local a = {}
	local text = VanasKoSListFrameSearchBox:GetText():lower():gsub("%%", ""):gsub("([%^%(%)%.%[%]%*%+%-%?])","%%%1");
	
	for k,v in pairs(t) do
		if(fFilter) then
			if(fFilter(self, k, v, text)) then
				table.insert(a, k)
			end
		else
			table.insert(a, k)
		end
	end
	table.sort(a, fSort)
	local i = 0      -- iterator variable
	local iter = function ()   -- iterator function
		i = i + 1
		if a[i] == nil then 
			return nil
		else 
			return a[i], t[a[i]]
		end
	end
	return iter
end

function VanasKoSGUI:SortedList(list)
	local sortListBy = self.db.profile.sortListBy;
	local sortFunction = nil;
	
	if(VANASKOS.showList == "PLAYERKOS" or VANASKOS.showList == "HATELIST" or VANASKOS.showList == "NICELIST") then
		if(sortListBy == "level") then
			-- sort by level
			sortFunction = function(val1, val2) 
								local list = VanasKoS:GetList("PLAYERDATA");
								if(list ~= nil) then
									local cmp1 = 0;
									local cmp2 = 0;
									if(list[val1] ~= nil and list[val1].level ~= nil) then
										cmp1 = list[val1].level;
									end
									if(list[val2] ~= nil and list[val2].level ~= nil) then
										cmp2 = list[val2].level;
									end
									if(cmp1 < cmp2) then
										return true;
									else
										return false;
									end
								end
							end
		elseif(sortListBy == "lastseen") then
			-- sort by reason
			sortFunction = function(val1, val2) 
								local list = VanasKoS:GetList("PLAYERDATA");
								if(list ~= nil) then
									local cmp1 = 2^30;
									local cmp2 = 2^30;
									if(list[val1] ~= nil and list[val1].lastseen ~= nil) then
										cmp1 = time() - list[val1].lastseen;
									end
									if(list[val2] ~= nil and list[val2].lastseen ~= nil) then
										cmp2 = time() - list[val2].lastseen;
									end
									
									if(cmp1 < cmp2) then
										return true;
									else
										return false;
									end
								end
							end
		end
	end
	if(VANASKOS.showList == "PLAYERKOS" or 
		VANASKOS.showList == "GUILDKOS" or 
		VANASKOS.showList == "HATELIST" or 
		VANASKOS.showList == "NICELIST") then
		if(sortListBy == "reason") then
		-- sort by reason
			sortFunction = function(val1, val2)
					local list = VanasKoS:GetList(VANASKOS.showList);
					local str1 = list[val1].reason;
					local str2 = list[val2].reason;
					if(str1 == nil or str1 == "") then
						str1 = L["_Reason Unknown_"];
					end
					if(str2 == nil or str2 == "") then
						str2 = L["_Reason Unknown_"];
					end
					if(str1:lower() < str2:lower()) then
						return true;
					else
						return false;
					end
				end
		elseif(sortListBy == "creator") then
		-- sort by reason
			sortFunction = function(val1, val2)
					local list = VanasKoS:GetList(VANASKOS.showList);
					local str1 = list[val1].creator;
					local str2 = list[val2].creator;
					if(str1 == nil or str1 == "") then
						str1 = "";
					end
					if(str2 == nil or str2 == "") then
						str2 = "";
					end
					if(str1:lower() < str2:lower()) then
						return true;
					else
						return false;
					end
				end
		end
	end

	if(listHandler[VANASKOS.showList] and listHandler[VANASKOS.showList].FilterFunction) then
		return self:pairsByKeys(list, sortFunction, listHandler[VANASKOS.showList].FilterFunction);
	else
		return self:pairsByKeys(list, sortFunction, nil);
	end
end

local oldlist = "";
function VanasKoSGUI:RegisterList(listName, handlerObject)
	if(not handlerObject) then
		VanasKoS:Print("Error: No handlerObject for " .. listName);
		return;
	end
	if(not handlerObject.RenderButton) then
		VanasKoS:Print("Error: No RenderButton method for " .. listName);
		return;
	end
	listHandler[listName] = handlerObject;
end

function VanasKoSGUI:UnregisterList(listName)
	listHandler[listName] = nil;
end

function VanasKoSGUI:ScrollFrameUpdate()
	local listOffset = FauxScrollFrame_GetOffset(VanasKoSListScrollFrame);
	local listVar = self:GetCurrentShownList();
	local listIndex = 1;
	local buttonIndex = 1;

	if(listVar == nil) then
		VANASKOS.selectedEntry = nil;
		self:GUIHideButtons(1, 10);
		return nil;
	end
	
	-- stupid fix that the dropdown selection is correct if showList is set external
	UIDropDownMenu_SetSelectedValue(VanasKoSFrameChooseListDropDown, VANASKOS.showList);

	if(oldlist ~= VANASKOS.showList) then
		if(listHandler[oldlist] and listHandler[oldlist].HideList) then
			listHandler[oldlist]:HideList(oldlist);
		end
		if(listHandler[VANASKOS.showList] and listHandler[VANASKOS.showList].ShowList) then
			listHandler[VANASKOS.showList]:ShowList(VANASKOS.showList);
		end
	end
	
	for k,v in self:SortedList(listVar) do
 		if((listIndex-1) < listOffset) then
		else
			if(buttonIndex <= 10) then
				local buttonText1 = getglobal("VanasKoSListFrameListButton" ..  buttonIndex .. "ButtonTextName");
				local buttonText2 = getglobal("VanasKoSListFrameListButton" ..  buttonIndex .. "ButtonTextReason");
				local button = getglobal("VanasKoSListFrameListButton" .. buttonIndex);
				button:SetID(listIndex);
				if(listIndex == VANASKOS.selectedEntry) then
					button:LockHighlight();
				else
					button:UnlockHighlight();
				end
				
				if(listHandler[VANASKOS.showList] ~= nil) then
					listHandler[VANASKOS.showList]:RenderButton(VANASKOS.showList, buttonIndex, button, k, v, buttonText1, buttonText2);
				end
				
				buttonIndex = buttonIndex + 1;
			end
		end
		listIndex = listIndex + 1;
	end
	
	if(listIndex <= 10) then
		self:GUIHideButtons(listIndex, 10);
	end
	
	if(listIndex == 1) then
		VANASKOS.selectedEntry = nil;
	else
		if(VANASKOS.selectedEntry == nil) then
			VANASKOS.selectedEntry = 1;
			self:ScrollFrameUpdate();
		end
		if(VANASKOS.selectedEntry >= listIndex) then
			VANASKOS.selectedEntry = 1;
			self:ScrollFrameUpdate();
		end
	end

	-- 34 = Hoehe VanasKoSListFrameListButtonTemplate
	-- scrollframe, maxnum, to_display, height
	FauxScrollFrame_Update(VanasKoSListScrollFrame, listIndex-1, 10, 34);
	
	oldlist = VANASKOS.showList;
end

function VanasKoSGUI:AddEntry()
	if(VANASKOS.showList == "GUILDKOS") then
		VANASKOS.LastNameEntered = GetGuildInfo("target");
	elseif(VANASKOS.showList == "SYNCPLAYER") then
		VANASKOS.LastNameEntered = nil;
	else
		VANASKOS.LastNameEntered = UnitName("target");
	end
	if(VANASKOS.LastNameEntered) then
		if(UnitIsPlayer("target")) then
			StaticPopup_Show("VANASKOS_ADD_REASON_ENTRY");
		else
			StaticPopup_Show("VANASKOS_ADD_ENTRY");
		end
	else
		StaticPopup_Show("VANASKOS_ADD_ENTRY");
	end
end

function VanasKoS_GUIOnScroll()
	VanasKoSGUI:ScrollFrameUpdate();
end

function VanasKoSGUI:Update()
	if(not VanasKoSFrame:IsVisible()) then
		return nil;
	end
	
	if(VanasKoSFrame.selectedTab == 1) then
		VanasKoSFrameTopLeft:SetTexture("Interface\\PaperDollInfoFrame\\UI-Character-General-TopLeft");
		VanasKoSFrameTopRight:SetTexture("Interface\\PaperDollInfoFrame\\UI-Character-General-TopRight");
		VanasKoSFrameBottomLeft:SetTexture("Interface\\FriendsFrame\\UI-FriendsFrame-BotLeft");
		VanasKoSFrameBottomRight:SetTexture("Interface\\FriendsFrame\\UI-FriendsFrame-BotRight");
		
		VanasKoSFrameTitleText:SetText(VANASKOS.NAME .. " - " .. L["Lists"]);
		self:GUIFrame_ShowSubFrame("VanasKoSListFrame");
		self:ScrollFrameUpdate();
	end
	if(VanasKoSFrame.selectedTab == 2) then
		VanasKoSFrameTopLeft:SetTexture("Interface\\PaperDollInfoFrame\\UI-Character-General-TopLeft");
		VanasKoSFrameTopRight:SetTexture("Interface\\PaperDollInfoFrame\\UI-Character-General-TopRight");
		VanasKoSFrameBottomLeft:SetTexture("Interface\\PaperDollInfoFrame\\UI-Character-General-BottomLeft");
		VanasKoSFrameBottomRight:SetTexture("Interface\\PaperDollInfoFrame\\UI-Character-General-BottomRight");

		self:GUIFrame_ShowSubFrame("VanasKoSAboutFrame");
		VanasKoSFrameTitleText:SetText(VANASKOS.NAME .. " - " .. L["About"]);
	end
end

function string.Capitalize( str )
    if(GetLocale() == "koKR") then return str end
	if(str == nil) then
		return "error"; 
	end
    return string.upper( string.sub( str, 1, 1 ) )..string.sub( str, 2 )
end

function VanasKoSGUI:Toggle()
	-- show/hide the frame: if not visible, show it via blizzard uipanel function if it wasn't moved, if moved just do a Show()
	if(VanasKoSFrame:IsVisible()) then
		if(self.db.profile.GUIMoved) then
			VanasKoSFrame:Hide();
		else
			HideUIPanel(VanasKoSFrame);
		end
	else
		VanasKoSListFrame:SetParent("VanasKoSFrame");
		VanasKoSListFrame:SetAllPoints();
		
		if(VanasKoSGUI.db.profile.GUIMoved) then
			VanasKoSFrame:Show();
		else
			ShowUIPanel(VanasKoSFrame);
		end
	end
end

--[[---------------------------------------------------------------------------------------------------
				Popup Dialog
-----------------------------------------------------------------------------------------------------]]
StaticPopupDialogs["VANASKOS_ADD_REASON_ENTRY"] = {
	text = L["Reason"],
	button1 = L["Accept"],
	button2 = L["Cancel"],
	hasEditBox = 1,
	maxLetters = 40,
	OnAccept = function()
		local editBox = getglobal(this:GetParent():GetName().."EditBox");
		local reason = editBox:GetText();
		if(reason == nil or reason == "") then
			reason = L["_Reason Unknown_"];
		end
		VanasKoS:AddEntry(VANASKOS.showList, VANASKOS.LastNameEntered, { ['reason'] = reason });
		VanasKoSGUI:Update();
	end,
	EditBoxOnEnterPressed = function()
		local editBox = getglobal(this:GetParent():GetName().."EditBox");
		local reason = editBox:GetText();
		if(reason == nil or reason == "") then
			reason = L["_Reason Unknown_"];
		end
		VanasKoS:AddEntry(VANASKOS.showList, VANASKOS.LastNameEntered, { ['reason'] = reason });
		VanasKoSGUI:Update();
		this:GetParent():Hide();
	end,
	OnShow = function()
		getglobal(this:GetName().."EditBox"):SetFocus();
	end,
	OnHide = function()
		if(ChatFrameEditBox:IsVisible() ) then
			ChatFrameEditBox:SetFocus();
		end
		getglobal(this:GetName().."EditBox"):SetText("");
	end,
	EditBoxOnEscapePressed = function()
		this:GetParent():Hide();
	end,
	timeout = 0,
	exclusive = 1,
	whileDead = 1,
	hideOnEscape = 1
}

StaticPopupDialogs["VANASKOS_ADD_ENTRY"] = {
	text = L["Name"],
	button1 = L["Accept"],
	button2 = L["Cancel"],
	hasEditBox = 1,
	maxLetters = 40,
	OnAccept = function()
		local editBox = getglobal(this:GetParent():GetName().."EditBox");
		VANASKOS.LastNameEntered = editBox:GetText();
		if(VANASKOS.showList == "SYNCPLAYER") then
			VanasKoS:AddEntry(VANASKOS.showList, VANASKOS.LastNameEntered,  { ['reason'] = "" });
			return;
		end
		if(VANASKOS.LastNameEntered ~= "") then
			StaticPopup_Show("VANASKOS_ADD_REASON_ENTRY");
		end
	end,
	EditBoxOnEnterPressed = function()
		local editBox = getglobal(this:GetParent():GetName().."EditBox");
		VANASKOS.LastNameEntered = editBox:GetText();
		if(VANASKOS.showList == "SYNCPLAYER") then
			VanasKoS:AddEntry(VANASKOS.showList, VANASKOS.LastNameEntered,  { ['reason'] = "" });
			this:GetParent():Hide();
			return;
		end
		if(VANASKOS.LastNameEntered ~= "") then
			StaticPopup_Show("VANASKOS_ADD_REASON_ENTRY");
		end
	end,
	OnShow = function()
		getglobal(this:GetName().."EditBox"):SetText("");
		getglobal(this:GetName().."EditBox"):SetFocus();
	end,
	OnHide = function()
		if(ChatFrameEditBox:IsVisible() ) then
			ChatFrameEditBox:SetFocus();
		end
		getglobal(this:GetName().."EditBox"):SetText("");
	end,
	EditBoxOnEscapePressed = function()
		this:GetParent():Hide();
	end,
	timeout = 0,
	exclusive = 1,
	whileDead = 1,
	hideOnEscape = 1
}

StaticPopupDialogs["VANASKOS_CHANGE_ENTRY"] = {
	text = L["Reason"],
	button1 = L["Accept"],
	button2 = L["Cancel"],
	hasEditBox = 1,
	maxLetters = 100,
	OnAccept = function()
		local editBox = getglobal(this:GetParent():GetName().."EditBox");
		VanasKoSGUI:GUIChangeKoSReason(editBox:GetText());
	end,
	EditBoxOnEnterPressed = function()
		local editBox = getglobal(this:GetParent():GetName().."EditBox");
		VanasKoSGUI:GUIChangeKoSReason(editBox:GetText());
		this:GetParent():Hide();
	end,
	OnShow = function()
		getglobal(this:GetName().."EditBox"):SetFocus();
	end,
	OnHide = function()
		if(ChatFrameEditBox:IsVisible() ) then
			ChatFrameEditBox:SetFocus();
		end
		getglobal(this:GetName().."EditBox"):SetText("");
	end,
	EditBoxOnEscapePressed = function()
		this:GetParent():Hide();
	end,
	timeout = 0,
	exclusive = 1,
	whileDead = 1,
	hideOnEscape = 1
}
